# © 2019 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class MailActivity(models.Model):
    _inherit = "mail.activity"

    activity_type_id = fields.Many2one(
        domain="""[
            '|', ('res_model_id', '=', False), ('res_model_id', '=', res_model_id),
            '|', ('ur_id','=',False), ('ur_id','=',context.get('current_ur_id', False))
        ]
        """,
    )

    @api.model
    def get_activity_data(self, res_model, domain):
        """
        Surcharge la fonction parente pour n'afficher que les activités liées à l'UR
        dans la vue Activité
        """
        result = super(MailActivity, self).get_activity_data(res_model, domain)
        activity_type_infos = []
        activity_type_ids = self.env["mail.activity.type"].search(
            [
                "|",
                ("res_model_id.model", "=", res_model),
                ("res_model_id", "=", False),
                "|",
                ("ur_id", "=", False),
                ("ur_id", "=", self.env.context.get("current_ur_id", False)),
            ]
        )
        for elem in sorted(activity_type_ids, key=lambda item: item.sequence):
            mail_template_info = []
            for mail_template_id in elem.mail_template_ids:
                mail_template_info.append(
                    {"id": mail_template_id.id, "name": mail_template_id.name}
                )
            activity_type_infos.append([elem.id, elem.name, mail_template_info])

        result["activity_types"] = activity_type_infos
        return result
